/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.beans;

/**
 * 更新規則と名前で拘束された引数情報のリストを格納する機能を提供します。
 */
public class BindArgumentsInfo extends FeatureInfo {

    /* 引数の型。 */
    private Class[] parameterTypes;

    /* 引数の値。 */
    private Object[] parameterValues;

    /* 引数拘束名。 */
    private String[] parameterNames;

    /* 引数拘束ルール。 */
    private int[] parameterRules;

    /* 引数情報。 */
    private BindArgumentInfo[] arguments;

    /**
     * デフォルトコンストラクタ。
     */
    public BindArgumentsInfo() {
        // no op
    }

    /**
     * 引数情報の配列を指定して初期化します。
     * 
     * @param arguments
     *            引数の情報
     */
    public BindArgumentsInfo(BindArgumentInfo[] arguments) {
        setArguments(arguments);
    }

    /*
     * Property
     */

    /**
     * 引数の値を返却します。
     * 
     * @return 引数の値
     */
    public Object[] getParameterValues() {
        return parameterValues;
    }

    /**
     * 引数の型を返却します。
     * 
     * @return 引数の型
     */
    public Class[] getParameterTypes() {
        return parameterTypes;
    }

    /**
     * 引数拘束名を返却します。
     * 
     * @return 引数拘束名
     */
    public String[] geParameterNames() {
        return parameterNames;
    }

    /**
     * 引数の拘束ルールを返却します。
     * 
     * @return 引数の拘束ルール
     */
    public int[] getParameterRules() {
        return parameterRules;
    }

    /**
     * 引数情報の配列を返却します。
     * 
     * @return 引数情報の配列
     */
    public BindArgumentInfo[] getArguments() {
        return arguments;
    }

    /**
     * 引数情報の配列を格納します。
     * 
     * @param args
     *            引数情報の配列
     */
    public void setArguments(BindArgumentInfo[] args) {
        if (args == null) {
            throw new NullPointerException("argument is null.");
        }
        Class[] types = new Class[args.length];
        Object[] values = new Object[args.length];
        String[] names = new String[args.length];
        int[] rules = new int[args.length];
        for (int i = 0; i < args.length; i++) {
            types[i] = args[i].getType();
            values[i] = args[i].getValue();
            names[i] = args[i].getBindName();
            rules[i] = args[i].getBindRule();
        }
        this.parameterTypes = types;
        this.parameterValues = values;
        this.parameterNames = names;
        this.parameterRules = rules;
        this.arguments = args;
    }
}
