/*
 * shohaku Copyright (C) 2005 tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
package shohaku.core.collections;

import java.util.Collection;
import java.util.Iterator;

import shohaku.core.collections.wrapper.WrappedCollection;

/**
 * <code>Collection</code>インタフェースのユーティリティメソッドを提供します。
 */
public class CollectionsUtils {

    /**
     * コレクション型にラッピングしたコレクションを返却します。 実装型に固有の機能へのアクセスを制限します。
     * 
     * @param coll
     *            ラップするコレクション
     * @return 実装をラッピングしたコレクション
     */
    public static Collection wrappedCollection(Collection coll) {
        return new WrappedCollection(coll);
    }

    /**
     * コレクションに反復子の要素を全て追加します。
     * 
     * @param c
     *            追加先のコレクション
     * @param elements
     *            追加する反復子
     * @return 引数のコレクション参照
     */
    public static Collection addAll(Collection c, Iterator elements) {
        while (elements.hasNext()) {
            c.add(elements.next());
        }
        return c;
    }
}
