/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.collections.params;

import java.util.List;

import shohaku.core.collections.KayValueIteratorUtils;

/**
 * パラメータリストAPIのユーティリティメソッドを提供します。
 */
public class ParametersUtils {

    /** 空のパラメータリスト。 */
    public static final Parameters EMPTY_PARAMETERS = new Parameters();

    /** 空の値が可変のパラメータリスト。 */
    public static final ModifiableParameters EMPTY_MODIFIABLE_PARAMETERS = new ModifiableParameters();

    /**
     * 指定された配列の要素を名前として値を<code>null</code>で値が可変のパラメータリストを初期化して返却します。
     * 
     * @param names
     *            名前の配列
     * @return 生成されたパラメータリスト
     */
    public static ModifiableParameters namesModifiableParameters(Object[] names) {
        return new ModifiableParameters(KayValueIteratorUtils.defaultValueKayValueIterator(names, null));
    }

    /**
     * 指定されたリストの要素を名前として値を<code>null</code>で値が可変のパラメータリストを初期化して返却します。
     * 
     * @param names
     *            名前のリスト
     * @return 生成されたパラメータリスト
     */
    public static ModifiableParameters namesModifiableParameters(List names) {
        return new ModifiableParameters(KayValueIteratorUtils.defaultValueKayValueIterator(names, null));
    }

    /**
     * 二つの配列を名前と値として同一のインデックスで関連付けて不変パラメータリストを生成して返却します。
     * 
     * @param names
     *            名前の配列
     * @param values
     *            値の配列
     * @return 生成されたパラメータリスト
     */
    public static Parameters nameValueParameters(Object[] names, Object[] values) {
        return new Parameters(KayValueIteratorUtils.indexMappingKayValueIterator(names, values));
    }

    /**
     * 二つのリストを名前と値として同一のインデックスで関連付けて不変パラメータリストを生成して返却します。
     * 
     * @param names
     *            名前のリスト
     * @param values
     *            値のリスト
     * @return 生成されたパラメータリスト
     */
    public static Parameters nameValueParameters(List names, List values) {
        return new Parameters(KayValueIteratorUtils.indexMappingKayValueIterator(names, values));
    }

    /*
     * 変換メソッド
     */

    /**
     * 値が可変のパラメータリストから不変パラメータリストを生成して返却します。
     * 
     * @param parameters
     *            値が可変のパラメータリスト
     * @return 生成された不変パラメータリスト
     */
    public static Parameters getParameters(ModifiableParameters parameters) {
        return new Parameters(parameters.kayValueIterator());
    }

    /**
     * 不変パラメータリストから値が可変のパラメータリストを生成して返却します。
     * 
     * @param parameters
     *            値が可変のパラメータリスト
     * @return 生成された値が可変のパラメータリスト
     */
    public static ModifiableParameters getModifiableParameters(Parameters parameters) {
        return new ModifiableParameters(parameters.kayValueIterator());
    }

}
