/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.lang;

/**
 * 変更可能な数値型のインターフェースを提供します。<br>
 * <br>
 * 変更可能な数値型のメンバーは <code>java.lang.Number</code> を継承するクラスとしては定義しません。<br>
 * これは普遍性の特性を持つ <code>java.lang.Number</code> と、変更可能な数値型としての <code>VariableNumber</code> 型を基本的に別のデータ型と定義するためです。
 */
public interface VariableNumber extends java.io.Serializable {

    /**
     * 現在の値の <code>Number</code> 型表現を返却します。
     * 
     * @return 現在の値の <code>Number</code> 型表現
     */
    Number getValue();

    /**
     * 指定の値を格納します。 値を丸めたり切り捨てたりすることもあります。
     * 
     * @param value
     *            格納する値
     * @throws NullPointerException
     *             引数が<code>null</code>の場合
     */
    void setValue(Number value);

    /**
     * 指定の値を格納します。 値を丸めたり切り捨てたりすることもあります。
     * 
     * @param value
     *            格納する値
     * @throws NullPointerException
     *             引数が<code>null</code>の場合
     */
    void setValue(VariableNumber value);

    /**
     * 指定された数値を <code>byte</code> 型として返します。値を丸めたり切り捨てたりすることもあります。
     * 
     * @return このオブジェクトが表す数値を <code>byte</code> 型に変換した値
     */
    byte byteValue();

    /**
     * 指定された値を <code>short</code> 型として返します。値を丸めたり切り捨てたりすることもあります。
     * 
     * @return このオブジェクトが表す数値を <code>short</code> 型に変換した値
     */
    short shortValue();

    /**
     * 指定された値を <code>int</code> 型として返します。値を丸めたり切り捨てたりすることもあります。
     * 
     * @return このオブジェクトが表す数値を <code>int</code> 型に変換した値
     */
    int intValue();

    /**
     * 指定された数値を <code>long</code> 型として返します。値を丸めたり切り捨てたりすることもあります。
     * 
     * @return このオブジェクトが表す数値を <code>long</code> 型に変換した値
     */
    long longValue();

    /**
     * 指定された数値を <code>float</code> 型として返します。値を丸めることもあります。
     * 
     * @return このオブジェクトが表す数値を <code>float</code> 型に変換した値
     */
    float floatValue();

    /**
     * 指定された値を <code>double</code> 型として返します。値を丸めることもあります。
     * 
     * @return このオブジェクトが表す数値を <code>double</code> 型に変換した値
     */
    double doubleValue();

}
