/*
 * shohaku
 * Copyright (C) 2005  tomoya nagatani
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package shohaku.core.util;

/**
 * ロケールを階層データとする階層化リソースバンドルの束縛基準を算出する機能を提供します。
 */
public class LocaleResourceBundleBaseCalculator implements XResourceBundleBaseCalculator {

    /**
     * デフォルトコンストラクタ。
     */
    public LocaleResourceBundleBaseCalculator() {
        super();
    }

    /**
     * バンドルのデフォルトロケールを返却します。
     * 
     * @return デフォルトロケール
     * @see shohaku.core.util.XResourceBundleBaseCalculator#getDefaultBundleBase()
     */
    public Object getDefaultBundleBase() {
        return XResourceBundleHelper.getLocaleDefaultBundleBase();
    }

    /**
     * バンドル名から束縛基準の識別子を算出して返却します。
     * 
     * @param bundleBase
     *            束縛基準
     * @return バンドル名から束縛基準の識別子
     * @see shohaku.core.util.XResourceBundleBaseCalculator#candidateBundleId(java.lang.Object)
     */
    public String candidateBundleId(Object bundleBase) {
        return XResourceBundleHelper.candidateLocaleBundleId(bundleBase);
    }

    /**
     * バンドル名からロケールを算出して返却します。
     * 
     * @param baseName
     *            バンドルの基底名
     * @param bundleName
     *            算出元のバンドル名
     * @return 算出されたロケール
     * @see shohaku.core.util.XResourceBundleBaseCalculator#calculateBundleBase(java.lang.String, java.lang.String)
     */
    public Object calculateBundleBase(String baseName, String bundleName) {
        return XResourceBundleHelper.calculateLocaleBundleBase(baseName, bundleName);
    }

    /**
     * バンドルの検索候補となるロケールを分割したバンドル名を算出して返却します。
     * 
     * @param baseName
     *            バンドルの基底名
     * @param bundleBase
     *            ロケール
     * @return 算出されたバンドル名
     * @see shohaku.core.util.XResourceBundleBaseCalculator#candidateHierarchyBundleNames(java.lang.String,
     *      java.lang.Object)
     */
    public String[] candidateHierarchyBundleNames(String baseName, Object bundleBase) {
        return XResourceBundleHelper.candidateLocaleBundleNames(baseName, bundleBase);
    }

}